thumbnailz.core


apply-suffix-to-filenameclj

(apply-suffix-to-filename file-path suffix)

Returns file-path with suffix appended to the file name.

Returns file-path with suffix appended to the file name.
sourceraw docstring

change-path-extensionclj

(change-path-extension file-path new-ext)

Returns file-path with new-ext as file extension.

Returns file-path with new-ext as file extension.
sourceraw docstring

convert-to-pngclj

(convert-to-png image-path)

Returns the path of the new png created from image-path file. Saves the new png at the same level of image-path.

Returns the path of the new png created from image-path file.
Saves the new png at the same level of image-path.
sourceraw docstring

crop-circleclj

(crop-circle image-path dimension suffix)

Returns the path of a new circle image cropped from image-path with width and height equal to dimension. Saves the new png at the same level of image-path applying suffix to file name.

Returns the path of a new circle image cropped from image-path with width and height equal to dimension.
Saves the new png at the same level of image-path applying suffix to file name.
sourceraw docstring

crop-squareclj

(crop-square image-path dimension suffix)

Returns the path of a new square image resized from image-path with width and height euqal to dimension. If the image is not squared, it will be cropped from center by the min dimension. Saves the new png at the same level of image-path applying suffix to file name.

Returns the path of a new square image resized from image-path with width and height euqal to dimension.
If the image is not squared, it will be cropped from center by the min dimension.
Saves the new png at the same level of image-path applying suffix to file name.
sourceraw docstring

get-image-infoclj

(get-image-info image-path)

Returns information about the image located at image-path.

Returns information about the image located at image-path.
sourceraw docstring

get-image-object-heightclj

(get-image-object-height image)

Returns the height of the given image object

Returns the height of the given image object
sourceraw docstring

get-image-object-widthclj

(get-image-object-width image)

Returns the width of the given image object

Returns the width of the given image object
sourceraw docstring

load-image-from-pathclj

(load-image-from-path image-path)

Returns a BufferedImage loaded from image-path.

Returns a BufferedImage loaded from image-path.
sourceraw docstring

png-path?clj

(png-path? image-path)

Returns true if image-path is a string that ends with .png extension.

Returns true if image-path is a string that ends with .png extension.
sourceraw docstring

resize-imageclj

(resize-image src-image dimension)
(resize-image src-image width height)

Returns the BufferedImage resized by width and height. If only one dimension is specified, the biggest between widht and height is resized, maintaing the ratio of the other one.

Returns the BufferedImage resized by width and height.
If only one dimension is specified, the biggest between widht and height is resized, maintaing the ratio of the other one.
sourceraw docstring

resize-image-and-saveclj

(resize-image-and-save src-path dest-path dimension)
(resize-image-and-save src-path dest-path width height)

Returns the dest-path of the resized image located in src-path. Saves the image to the dest-path.

Returns the dest-path of the resized image located in src-path.
Saves the image to the dest-path.
sourceraw docstring

save-image-to-pathclj

(save-image-to-path image dest-path)

Saves the image to the dest-path and returns the dest-path

Saves the image to the dest-path and returns the dest-path
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries