(apply-suffix-to-filename file-path suffix)Returns file-path with suffix appended to the file name.
Returns file-path with suffix appended to the file name.
(change-path-extension file-path new-ext)Returns file-path with new-ext as file extension.
Returns file-path with new-ext as file extension.
(convert-to-png image-path)Returns the path of the new png created from image-path file. Saves the new png at the same level of image-path.
Returns the path of the new png created from image-path file. Saves the new png at the same level of image-path.
(crop-circle image-path dimension suffix)Returns the path of a new circle image cropped from image-path with width and height equal to dimension. Saves the new png at the same level of image-path applying suffix to file name.
Returns the path of a new circle image cropped from image-path with width and height equal to dimension. Saves the new png at the same level of image-path applying suffix to file name.
(crop-square image-path dimension suffix)Returns the path of a new square image resized from image-path with width and height euqal to dimension. If the image is not squared, it will be cropped from center by the min dimension. Saves the new png at the same level of image-path applying suffix to file name.
Returns the path of a new square image resized from image-path with width and height euqal to dimension. If the image is not squared, it will be cropped from center by the min dimension. Saves the new png at the same level of image-path applying suffix to file name.
(get-image-info image-path)Returns information about the image located at image-path.
Returns information about the image located at image-path.
(get-image-object-height image)Returns the height of the given image object
Returns the height of the given image object
(get-image-object-width image)Returns the width of the given image object
Returns the width of the given image object
(load-image-from-path image-path)Returns a BufferedImage loaded from image-path.
Returns a BufferedImage loaded from image-path.
(png-path? image-path)Returns true if image-path is a string that ends with .png extension.
Returns true if image-path is a string that ends with .png extension.
(resize-image src-image dimension)(resize-image src-image width height)Returns the BufferedImage resized by width and height. If only one dimension is specified, the biggest between widht and height is resized, maintaing the ratio of the other one.
Returns the BufferedImage resized by width and height. If only one dimension is specified, the biggest between widht and height is resized, maintaing the ratio of the other one.
(resize-image-and-save src-path dest-path dimension)(resize-image-and-save src-path dest-path width height)Returns the dest-path of the resized image located in src-path. Saves the image to the dest-path.
Returns the dest-path of the resized image located in src-path. Saves the image to the dest-path.
(save-image-to-path image dest-path)Saves the image to the dest-path and returns the dest-path
Saves the image to the dest-path and returns the dest-path
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |